@@ -12,10 +12,11 @@ log = logging.getLogger('flufl.i18n')
 
 
 @public
-def expand(template: str,
-           substitutions: Dict[str, str],
-           template_class: type = Template
-           ) -> str:
+def expand(
+    template: str,
+    substitutions: Dict[str, str],
+    template_class: type = Template,
+) -> str:
     """Expand string template with substitutions.
 
     :param template: A PEP 292 $-string template.
