@@ -2,7 +2,7 @@
 
 import string
 
-from typing import cast, Union
+from typing import Union, cast
 
 from public import public
 
@@ -14,7 +14,7 @@ _missing = object()
 class Template(string.Template):
     """Match any attribute path."""
 
-    idpattern = r'[_a-z][_a-z0-9.]*'
+    idpattern = r'[_a-z][_a-z0-9.]*[_a-z0-9]'
 
 
 @public
